@@ -3,6 +3,7 @@ from selenium import webdriver
 import json
 from selenium.common.exceptions import NoSuchElementException,ElementNotInteractableException,StaleElementReferenceException,UnexpectedAlertPresentException,InvalidSessionIdException,WebDriverException
 from selenium.webdriver.common.by import By
+from httpcore._exceptions import ConnectTimeout,ConnectError,ReadError,ReadTimeout
 from selenium.webdriver.support.ui import WebDriverWait
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.common import exceptions  
@@ -22,6 +23,7 @@ class Omegle_Translator():
         self.translator = Translator()
         self.google_lang_json = googletrans.LANGUAGES
         self.exception_s = (NoSuchElementException,ElementNotInteractableException,StaleElementReferenceException,UnexpectedAlertPresentException)
+        self.exceptions_http = (ConnectTimeout,ConnectError,ReadError,ReadTimeout)
         self.user_lang,self.stranger_lang  = self.change_language()
         self.stranger_status_active=False
         self.taking_input = False
@@ -29,11 +31,11 @@ class Omegle_Translator():
         self.input_text=''
         self.total_number_of_outputs = 0
         self.stranger_last_message = ''
+        self.open = False
 
     def get_cwd(self):
         return os.path.dirname(os.path.abspath(__file__))
          
-
     def change_language(self):
         print(self.b.purple_text('Here is the list of language CODE corresponding to their languages respectively.'))
         print(json.dumps(self.google_lang_json, indent=4, sort_keys=True))
@@ -154,10 +156,16 @@ class Omegle_Translator():
                 try:
 
                     os.environ["webdriver.chrome.driver"] = chromedriver
-                    self.driver = webdriver.Chrome(chromedriver)
+                    if not self.open:
+                        print(self.b.purple_text('Opening Chrome....'))
+                        self.driver = webdriver.Chrome(chromedriver)
+                        self.open = True
+                    else:
+                        print(self.b.purple_text('Chrome Already Opened....'))
 
                 except WebDriverException:
                     print(self.b.purple_text('You need to download chrome driver extension as per your chrome version from https://chromedriver.chromium.org/downloads ,and paste the extension in the directory {}'.format(self.get_cwd())))
+                    break
 
                 website = "https://www.omegle.com"
                 self.driver.get(website)
@@ -202,6 +210,9 @@ class Omegle_Translator():
             except InvalidSessionIdException:
                 break
 
+            except self.exceptions_http:
+                continue
+
     def start_chatting(self):
 
         while True:
